Name:           ocaml-lwt
Version:        5.6.1
Release:        %mkrel 2
Summary:        Cooperative light-weight thread library for OCaml
Group:          Development/OCaml
# The openssl linking exception is granted.
License:        LGPLv2+ with exceptions
URL:            https://ocsigen.org/lwt
Source0:        https://github.com/ocsigen/lwt/archive/%{version}/lwt-%{version}.tar.gz

BuildRequires:  ocaml >= 4.02.0
BuildRequires:  ocaml-findlib

BuildRequires:  dune >= 1.8.0
BuildRequires:  ocaml-dune-devel
BuildRequires:  ocaml-result-devel
BuildRequires:  ocaml-seq-devel
BuildRequires:  ocaml-cppo-devel >= 1.1.0

# lwt.unix dependencies
BuildRequires:  ocaml-mmap-devel >= 1.1.0
BuildRequires:  ocaml-ocplib-endian-devel
BuildRequires:  ocaml-compiler-libs-janestreet-devel

# lwt_luv dependencies.
BuildRequires:  ocaml-luv-devel

# lwt_react dependencies.
BuildRequires:  ocaml-react-devel

# lwt_ppx dependencies.
BuildRequires:  ocaml-ppxlib-devel >= 0.16.0

BuildRequires:  pkgconfig(libev)
BuildRequires:  pkgconfig(glib-2.0)

# Many files were moved to the main package
Conflicts:      ocaml-lwt-devel < 4.4.0

%description
Lwt is a lightweight thread library for OCaml.
This library of cooperative threads is implemented in monadic style.
With respect to preemptive threads, cooperative threads are not using a
scheduler to distribute processor time between threads. Instead of this,
each thread must tell the others that he wants to let them work.
This library is part of the Ocsigen project.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-mmap-devel%{?_isa}
Requires:       ocaml-ocplib-endian-devel%{?_isa}
Requires:       ocaml-result-devel%{?_isa}
Requires:       ocaml-seq-devel%{?_isa}
Requires:       pkgconfig(libev)

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%package        luv
Summary:        Libuv engine for lwt
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    luv
This package contains a libuv engine for lwt.

%package        luv-devel
Summary:        Development files for ocaml-lwt-luv

Requires:       %{name}-luv%{?_isa} = %{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       ocaml-luv-devel%{?_isa}
Requires:       ocaml-result-devel%{?_isa}

%description    luv-devel
The %{name}-luv-devel package contains libraries and signature files for
developing applications that use %{name}-luv.

%package        react
Summary:        Helpers for using React with Lwt
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    react
Helpers for using React with Lwt.

%package        react-devel
Summary:        Development files for ocaml-lwt-react
Group:          Development/OCaml
Requires:       %{name}-react = %{version}-%{release}

%description    react-devel
The %{name}-react-devel package contains libraries and signature files for
developing applications that use %{name}-react.

%package        ppx
Summary:        PPX syntax for Lwt
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    ppx
PPX syntax for Lwt, providing something similar to async/await from JavaScript.

%package        ppx-devel
Summary:        Development files for ocaml-lwt-ppx
Group:          Development/OCaml
Requires:       %{name}-ppx%{?_isa} = %{version}-%{release}
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}
Requires:       ocaml-ppxlib-devel%{?_isa}

%description    ppx-devel
The %{name}-ppx-devel package contains libraries and signature files for
developing applications that use %{name}-ppx.

%prep
%autosetup -n lwt-%{version}

# We do not have MultiCore OCaml, so do not have domainslib.  Remove lwt_domain
# so we do not try to build it.  Revisit this when OCaml 5.x is released.
rm -rf src/domain
rm -rf test/domain
rm lwt_domain.opam

# It looks like one test fails.
# Actually, it looks like all the "mcast" tests fail in koji.
# They should probably be disabled via a patch, but this works for now.
sed 's,test_mcast "mcast-join-loop" true true;,(*test_mcast "mcast-join-loop" true true;*),' -i test/unix/test_mcast.ml
sed 's,test_mcast "mcast-join-noloop" true false;,(*test_mcast "mcast-join-noloop" true false;*),' -i test/unix/test_mcast.ml
sed 's,test_mcast "mcast-nojoin-loop" false true;,(*test_mcast "mcast-nojoin-loop" false true;*),' -i test/unix/test_mcast.ml
sed 's,test_mcast "mcast-nojoin-noloop" false false;,(*test_mcast "mcast-nojoin-noloop" false false;*),' -i test/unix/test_mcast.ml

%build
# Enable libev and pthread.
dune exec src/unix/config/discover.exe -- --save \
     --use-libev true --use-pthread true

dune build --profile=release --verbose

%install
dune install --profile=release --destdir %{buildroot}

#chrpath --delete $OCAMLFIND_DESTDIR/stublibs/dll*.so

# Remove spurious dune-installed documentation.
rm -rf %{buildroot}/%{_prefix}/doc

# Dummy package for tests, no need to distribute it
rm -rf %{buildroot}/%{_libdir}/ocaml/lwt_ppx_let/

%check
dune runtest --profile=release || :

%files
%doc CHANGES README.md
%license LICENSE.md
%{_libdir}/ocaml/lwt
%{_libdir}/ocaml/stublibs/dlllwt_unix_stubs.so
%ifarch %{ocaml_native_compiler}
%exclude %{_libdir}/ocaml/lwt/*.a
%exclude %{_libdir}/ocaml/lwt/*.cmxa
%exclude %{_libdir}/ocaml/lwt/*.cmx
%endif
%exclude %{_libdir}/ocaml/lwt/*.mli

%files devel
%doc CHANGES README.md
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/lwt/*.a
%{_libdir}/ocaml/lwt/*.cmxa
%{_libdir}/ocaml/lwt/*.cmx
%endif
%{_libdir}/ocaml/lwt/*.mli
#{_libdir}/ocaml/stublibs/*.so

%files luv
%doc CHANGES README.md
%license LICENSE.md
%dir %{_libdir}/ocaml/lwt_luv/
%{_libdir}/ocaml/lwt_luv/META
%{_libdir}/ocaml/lwt_luv/dune-package
%{_libdir}/ocaml/lwt_luv/opam
%{_libdir}/ocaml/lwt_luv/*.cma
%{_libdir}/ocaml/lwt_luv/*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/lwt_luv/*.cmxs
%endif

%files luv-devel
%doc CHANGES README.md
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/lwt_luv/*.a
%{_libdir}/ocaml/lwt_luv/*.cmxa
%{_libdir}/ocaml/lwt_luv/*.cmx
%endif
%{_libdir}/ocaml/lwt_luv/*.cmt
%{_libdir}/ocaml/lwt_luv/*.cmti
%{_libdir}/ocaml/lwt_luv/*.ml
%{_libdir}/ocaml/lwt_luv/*.mli
 
%files react
%doc CHANGES README.md
%license LICENSE.md
%dir %{_libdir}/ocaml/lwt_react
%{_libdir}/ocaml/lwt_react/META
%{_libdir}/ocaml/lwt_react/opam
%{_libdir}/ocaml/lwt_react/*dune*
%{_libdir}/ocaml/lwt_react/*.cma
%{_libdir}/ocaml/lwt_react/*.cmi
%{_libdir}/ocaml/lwt_react/*.cmxs

%files react-devel
%doc CHANGES README.md
%{_libdir}/ocaml/lwt_react/*.a
%{_libdir}/ocaml/lwt_react/*.cmt*
%{_libdir}/ocaml/lwt_react/*.cmxa
%{_libdir}/ocaml/lwt_react/*.cmx
%{_libdir}/ocaml/lwt_react/*.ml
%{_libdir}/ocaml/lwt_react/*.mli

%files ppx
%dir %{_libdir}/ocaml/lwt_ppx
%{_libdir}/ocaml/lwt_ppx/META
%{_libdir}/ocaml/lwt_ppx/opam
%{_libdir}/ocaml/lwt_ppx/*dune*
%{_libdir}/ocaml/lwt_ppx/*.cma
%{_libdir}/ocaml/lwt_ppx/*.cmi
%{_libdir}/ocaml/lwt_ppx/*.cmxs
%{_libdir}/ocaml/lwt_ppx/*.exe

%files ppx-devel
%doc CHANGES README.md
%{_libdir}/ocaml/lwt_ppx/*.a
%{_libdir}/ocaml/lwt_ppx/*.cmt*
%{_libdir}/ocaml/lwt_ppx/*.cmxa
%{_libdir}/ocaml/lwt_ppx/*.cmx
%{_libdir}/ocaml/lwt_ppx/*.ml
%{_libdir}/ocaml/lwt_ppx/*.mli


%changelog
* Wed Dec 14 2022 pterjan <pterjan> 5.6.1-2.mga9
+ Revision: 1922208
- Fix BuildRequires
- Rebuild for new ppxlib

* Sun Oct 09 2022 pterjan <pterjan> 5.6.1-1.mga9
+ Revision: 1895756
- Update to 5.6.1

* Thu May 19 2022 pterjan <pterjan> 5.5.0-2.mga9
+ Revision: 1859293
- Rebuild for OCaml 4.14

* Mon May 16 2022 pterjan <pterjan> 5.5.0-1.mga9
+ Revision: 1858440
- Update to 5.5.0

* Wed Oct 13 2021 tv <tv> 5.4.2-1.mga9
+ Revision: 1751148
- 5.4.2

* Thu Mar 25 2021 tv <tv> 5.4.0-3.mga9
+ Revision: 1709800
- Fix devel deps

* Sat Mar 20 2021 tv <tv> 5.4.0-2.mga9
+ Revision: 1705030
- Add some deps to devel sub pkg so that ocaml-ounit's testsuite doesn't choke

* Fri Mar 19 2021 tv <tv> 5.4.0-1.mga9
+ Revision: 1705017
- 5.4.0
- add luv subpkg
- 5.3.0
- 5.4.0

* Sat Jan 09 2021 pterjan <pterjan> 4.4.0-2.mga8
+ Revision: 1670230
- Add missing conflicts after file moves

* Fri Feb 28 2020 umeabot <umeabot> 4.4.0-1.3.mga8
+ Revision: 1551744
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 4.4.0-1.2.mga8
+ Revision: 1545148
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 tv <tv> 4.4.0-1.1.mga8
+ Revision: 1484111
- enable mmap+ocplib-endian support

* Sun Jan 26 2020 tv <tv> 4.4.0-1.mga8
+ Revision: 1483105
- new release + rebuild for ocaml-4.10

* Thu Oct 25 2018 daviddavid <daviddavid> 4.1.0-2.mga7
+ Revision: 1325460
- rebuild for new ocaml 4.07.1

* Thu Oct 11 2018 daviddavid <daviddavid> 4.1.0-1.mga7
+ Revision: 1319602
- new version: 4.1.0
- switch to jbuilder/dune buildsystem
- lwt_react and lwt_ppx are now separate opam packages, built from this tarball
- split lwt_react and lwt_ppx into ocaml-lwt-react and ocaml-lwt-ppx subpkgs

* Sun Sep 23 2018 umeabot <umeabot> 2.5.0-4.mga7
+ Revision: 1299891
- Mageia 7 Mass Rebuild

* Tue Mar 27 2018 daviddavid <daviddavid> 2.5.0-3.mga7
+ Revision: 1212734
- rebuild for new ocaml-react 1.2.1

* Mon Feb 05 2018 daviddavid <daviddavid> 2.5.0-2.mga7
+ Revision: 1199071
- BR texlive-dist to fix build (for File `pdftex.def' not found)

* Tue Dec 05 2017 tv <tv> 2.5.0-1.mga7
+ Revision: 1181321
- BR ocaml-ppx_tools
- new release
- new URL
- make it support --short-circuit
- it no more needs ocaml-text
- rebuild for new ocaml

* Thu Oct 12 2017 daviddavid <daviddavid> 2.4.5-8.mga7
+ Revision: 1171367
- rebuild for fixed ocaml (use standard ISO C99 types {u}uint{32,64}_t)

* Sun Sep 17 2017 daviddavid <daviddavid> 2.4.5-7.mga7
+ Revision: 1154980
- rebuild for new ocaml-ssl

* Mon Sep 26 2016 pterjan <pterjan> 2.4.5-6.mga6
+ Revision: 1056419
- Rebuild for fix in ocaml

* Mon Feb 01 2016 pterjan <pterjan> 2.4.5-5.mga6
+ Revision: 930656
- Rebuild for new ocaml

* Wed Oct 15 2014 umeabot <umeabot> 2.4.5-4.mga5
+ Revision: 745124
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 malo <malo> 2.4.5-3.mga5
+ Revision: 737481
- add documentation

* Sun Oct 05 2014 tv <tv> 2.4.5-2.mga5
+ Revision: 736966
- rebuild for broken deps
- rebuild for ocaml(React)
+ malo <malo>
- update to 2.4.5

* Tue Sep 16 2014 umeabot <umeabot> 2.4.3-4.mga5
+ Revision: 683061
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 2.4.3-3.mga4
+ Revision: 534161
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 blue_prawn <blue_prawn> 2.4.3-2.mga4
+ Revision: 476334
- rebuild for ocaml-4.01.0, and integrated patch from Anil Madhavapeddy

* Fri Aug 02 2013 blue_prawn <blue_prawn> 2.4.3-1.mga4
+ Revision: 462607
- updated to last version 2.4.3

* Sun Jan 13 2013 umeabot <umeabot> 2.4.2-5.mga3
+ Revision: 361451
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 malo <malo> 2.4.2-4.mga3
+ Revision: 324096
- rebuild for new ocaml

* Sat Oct 20 2012 malo <malo> 2.4.2-3.mga3
+ Revision: 308590
- update RPM group

* Tue Oct 02 2012 blue_prawn <blue_prawn> 2.4.2-2.mga3
+ Revision: 302107
- adapt the Fedora patch (by Richard W.M. Jones and Scott Tsai) for lwt 2.4.2
- uported patch for ocaml 4.00 from Fedora
- build requires ocaml-compiler-libs
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 2.4.2-1.mga3
+ Revision: 300203
- updated to last version 2.4.2
- new rpm group for ocaml and documentation

* Sat Aug 25 2012 blue_prawn <blue_prawn> 2.4.1-1.mga3
+ Revision: 283978
- updated to last version 2.4.1
- also provide examples/ and tests/

* Thu Aug 02 2012 blue_prawn <blue_prawn> 2.4.0-1.mga3
+ Revision: 278022
- updated to last version 2.4.0

* Thu Mar 29 2012 malo <malo> 2.3.2-3.mga2
+ Revision: 227415
- missing requires libev-devel

* Tue Jan 31 2012 malo <malo> 2.3.2-2.mga2
+ Revision: 203728
- fix hardcoded lib path for x86_64

* Thu Dec 22 2011 malo <malo> 2.3.2-1.mga2
+ Revision: 186096
- missing BuildRequires ocaml-react-devel
- spec clean-up after import
- missing requires
- update to 2.3.2
- imported package ocaml-lwt

